Crate kcr_autoscaling_karmada_io

Crate kcr_autoscaling_karmada_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the autoscaling.karmada.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

autoscaling.karmada.io/v1alpha1

  • CronFederatedHPA
  • FederatedHPA

Modules

v1alpha1